==> gemrb-0.3.0.tar.gz: gemrb-0.3.0/gemrb/plugins/Core/Slider.h <==
/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: Slider.h 4698 2007-06-15 21:34:23Z avenger_teambg $
 *
 */

/**
 * @file Slider.h
 * Declares Slider widget for displaying scales and sliders for setting
 * numerical values
 * @author The GemRB Project
 */

#ifndef SLIDER_H
#define SLIDER_H

#include "Control.h"
#include "Sprite2D.h"
#include <math.h>

// !!! Keep these synchronized with GUIDefines.py !!!
#define IE_GUI_SLIDER_ON_CHANGE    0x02000000


#define IE_GUI_SLIDER_KNOB        0
#define IE_GUI_SLIDER_GRABBEDKNOB 1
#define IE_GUI_SLIDER_BACKGROUND  2

#ifdef WIN32

#ifdef GEM_BUILD_DLL
#define GEM_EXPORT __declspec(dllexport)
#else
#define GEM_EXPORT __declspec(dllimport)
#endif

#else
#define GEM_EXPORT
#endif

/**
 * @class Slider
 * Widget displaying sliders or scales for inputting numerical values
 * with a limited range
 */

class GEM_EXPORT Slider : public Control  {
public: 
	Slider(short KnobXPos, short KnobYPos, short KnobStep, unsigned short KnobStepsCount, bool Clear = false);
	~Slider();
	/** Draws the Control on the Output Display */
	void Draw(unsigned short x, unsigned short y);
	/** Returns the actual Slider Position */
	unsigned int GetPosition();
	/** Sets the actual Slider Position trimming to the Max and Min Values */
	void SetPosition(unsigned int pos);
	/** Sets the selected image */
	void SetImage(unsigned char type, Sprite2D * img);
	/** Sets the Text of the current control */
	int SetText(const char * string, int pos = 0);
	/** Sets the State of the Slider */
	void SetState(int arg) { State=(unsigned char) arg; }
	/** Redraws a slider which is associated with VariableName */
	void RedrawSlider(const char *VariableName, int Sum);

private: // Private attributes
	/** BackGround Image. If smaller than the Control Size, the image will be tiled. */
	Sprite2D * BackGround;
	/** Knob Image */
	Sprite2D * Knob;
	/** Grabbed Knob Image */
	Sprite2D * GrabbedKnob;
	/** Knob Starting X Position */
	short KnobXPos;
	/** Knob Starting Y Position */
	short KnobYPos;
	/** Knob Step Size */
	short KnobStep;
	/** Knob Steps Count */
	unsigned short KnobStepsCount;
	/** If true, on deletion the Slider will destroy the associated images */
	bool Clear;
	/** Actual Knob Status */
	unsigned char State;
	/** Slider Position Value */
	unsigned int Pos;
public: // Public Events
	/** Mouse Button Down */
	void OnMouseDown(unsigned short x, unsigned short y, unsigned char Button, unsigned short Mod);
	/** Mouse Button Up */
	void OnMouseUp(unsigned short x, unsigned short y, unsigned char Button, unsigned short Mod);
	/** Mouse Over Event */
	void OnMouseOver(unsigned short x, unsigned short y);
	/** Set handler for specified event */
	bool SetEvent(int eventType, const char *handler);
	/** OnChange Scripted Event Function Name */
	EventHandler SliderOnChange;
};

#endif

==> gemrb-0.3.2.tar.gz: gemrb-0.3.2/gemrb/plugins/Core/Slider.h <==
/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: Slider.h 5366 2008-09-28 14:54:41Z avenger_teambg $
 *
 */

/**
 * @file Slider.h
 * Declares Slider widget for displaying scales and sliders for setting
 * numerical values
 * @author The GemRB Project
 */

#ifndef SLIDER_H
#define SLIDER_H

#include "Control.h"
#include "Sprite2D.h"
#include <math.h>

// !!! Keep these synchronized with GUIDefines.py !!!
#define IE_GUI_SLIDER_ON_CHANGE    0x02000000


#define IE_GUI_SLIDER_KNOB        0
#define IE_GUI_SLIDER_GRABBEDKNOB 1
#define IE_GUI_SLIDER_BACKGROUND  2

#ifdef WIN32

#ifdef GEM_BUILD_DLL
#define GEM_EXPORT __declspec(dllexport)
#else
#define GEM_EXPORT __declspec(dllimport)
#endif

#else
#define GEM_EXPORT
#endif

/**
 * @class Slider
 * Widget displaying sliders or scales for inputting numerical values
 * with a limited range
 */

class GEM_EXPORT Slider : public Control  {
public: 
	Slider(short KnobXPos, short KnobYPos, short KnobStep, unsigned short KnobStepsCount, bool Clear = false);
	~Slider();
	/** Draws the Control on the Output Display */
	void Draw(unsigned short x, unsigned short y);
	/** Returns the actual Slider Position */
	unsigned int GetPosition();
	/** Sets the actual Slider Position trimming to the Max and Min Values */
	void SetPosition(unsigned int pos);
	/** Sets the selected image */
	void SetImage(unsigned char type, Sprite2D * img);
	/** Sets the Text of the current control */
	int SetText(const char * string, int pos = 0);
	/** Sets the State of the Slider */
	void SetState(int arg) { State=(unsigned char) arg; }
	/** Redraws a slider which is associated with VariableName */
	void RedrawSlider(const char *VariableName, int Sum);

private: // Private attributes
	/** BackGround Image. If smaller than the Control Size, the image will be tiled. */
	Sprite2D * BackGround;
	/** Knob Image */
	Sprite2D * Knob;
	/** Grabbed Knob Image */
	Sprite2D * GrabbedKnob;
	/** Knob Starting X Position */
	short KnobXPos;
	/** Knob Starting Y Position */
	short KnobYPos;
	/** Knob Step Size */
	short KnobStep;
	/** Knob Steps Count */
	unsigned short KnobStepsCount;
	/** If true, on deletion the Slider will destroy the associated images */
	bool Clear;
	/** Actual Knob Status */
	unsigned char State;
	/** Slider Position Value */
	unsigned int Pos;
public: // Public Events
	/** Mouse Button Down */
	void OnMouseDown(unsigned short x, unsigned short y, unsigned short Button,
		unsigned short Mod);
	/** Mouse Button Up */
	void OnMouseUp(unsigned short x, unsigned short y, unsigned short Button,
		unsigned short Mod);
	/** Mouse Over Event */
	void OnMouseOver(unsigned short x, unsigned short y);
	/** Set handler for specified event */
	bool SetEvent(int eventType, const char *handler);
	/** OnChange Scripted Event Function Name */
	EventHandler SliderOnChange;
};

#endif
